@@ -62,8 +62,9 @@ type Flags struct {
 	Summarize         bool     `yaml:"summarize"`
 	UseSIPrefix       bool     `yaml:"use-si-prefix"`
 	NoPrefix          bool     `yaml:"no-prefix"`
-	WriteConfig       bool     `yaml:"write-config"`
+	WriteConfig       bool     `yaml:"-"`
 	Style             Style    `yaml:"style"`
+	Sorting           Sorting  `yaml:"sorting"`
 }
 
 // Style define style config
@@ -83,6 +84,12 @@ type ColorStyle struct {
 	BackgroundColor string `yaml:"background-color"`
 }
 
+// Sorting defines default sorting of items
+type Sorting struct {
+	By    string `yaml:"by"`
+	Order string `yaml:"order"`
+}
+
 // App defines the main application
 type App struct {
 	Args        []string
@@ -229,6 +236,11 @@ func (a *App) createUI() (UI, error) {
 				ui.SetCurrentItemNameMaxLen(a.Flags.Style.ProgressModal.CurrentItemNameMaxLen)
 			})
 		}
+		if a.Flags.Sorting.Order != "" || a.Flags.Sorting.By != "" {
+			opts = append(opts, func(ui *tui.UI) {
+				ui.SetDefaultSorting(a.Flags.Sorting.By, a.Flags.Sorting.Order)
+			})
+		}
 
 		ui = tui.CreateUI(
 			a.TermApp,
