@@ -5,6 +5,7 @@ import (
 	"fmt"
 	"io"
 	"os"
+	"os/exec"
 	"runtime"
 	"runtime/debug"
 	"strings"
@@ -347,3 +348,26 @@ func (ui *UI) showInfo() {
 
 	ui.pages.AddPage("info", flex, true, true)
 }
+
+func (ui *UI) openItem() {
+	row, column := ui.table.GetSelection()
+	selectedFile, ok := ui.table.GetCell(row, column).GetReference().(fs.Item)
+	if !ok || selectedFile == ui.currentDir.GetParent() {
+		return
+	}
+
+	openBinary := "xdg-open"
+
+	switch runtime.GOOS {
+	case "darwin":
+		openBinary = "open"
+	case "windows":
+		openBinary = "Invoke-Item"
+	}
+
+	cmd := exec.Command(openBinary, selectedFile.GetPath())
+	err := cmd.Start()
+	if err != nil {
+		ui.showErr("Error opening", err)
+	}
+}
