@@ -139,6 +139,8 @@ func (ui *UI) handleMainActions(key *tcell.EventKey) *tcell.EventKey {
 		ui.handleDelete(true)
 	case 'v':
 		ui.showFile()
+	case 'o':
+		ui.openItem()
 	case 'i':
 		ui.showInfo()
 	case 'a':
@@ -223,8 +225,8 @@ func (ui *UI) handleDelete(shouldEmpty bool) {
 	}
 	// do not allow deleting parent dir
 	row, column := ui.table.GetSelection()
-	selectedFile := ui.table.GetCell(row, column).GetReference().(fs.Item)
-	if selectedFile == ui.currentDir.GetParent() {
+	selectedFile, ok := ui.table.GetCell(row, column).GetReference().(fs.Item)
+	if !ok || selectedFile == ui.currentDir.GetParent() {
 		return
 	}
 
