@@ -32,6 +32,7 @@ Item under cursor:
                [::b]d    [white:black:-]Delete file or directory
                [::b]e    [white:black:-]Empty file or directory
                [::b]v    [white:black:-]Show content of file
+               [::b]o    [white:black:-]Open file or directory in external program
                [::b]i    [white:black:-]Show info about item
 
 Sort by (twice toggles asc/desc):
@@ -76,6 +77,8 @@ type UI struct {
 	selectedTextColor       tcell.Color
 	selectedBackgroundColor tcell.Color
 	currentItemNameMaxLen   int
+	defaultSortBy           string
+	defaultSortOrder        string
 }
 
 // Option is optional function customizing the bahaviour of UI
@@ -114,6 +117,8 @@ func CreateUI(
 		selectedTextColor:       tview.Styles.TitleColor,
 		selectedBackgroundColor: tview.Styles.MoreContrastBackgroundColor,
 		currentItemNameMaxLen:   70,
+		defaultSortBy:           "size",
+		defaultSortOrder:        "desc",
 	}
 	for _, o := range opts {
 		o(ui)
@@ -206,8 +211,8 @@ func (ui *UI) StartUILoop() error {
 }
 
 func (ui *UI) resetSorting() {
-	ui.sortBy = "size"
-	ui.sortOrder = "desc"
+	ui.sortBy = ui.defaultSortBy
+	ui.sortOrder = ui.defaultSortOrder
 }
 
 func (ui *UI) rescanDir() {
